package de.java2html.eclipse;

import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.ui.plugin.AbstractUIPlugin;

import de.java2html.eclipse.preferences.ConversionOptionsPreferencesConverter;
import de.java2html.options.IConversionOptionsConstants;
import de.java2html.options.JavaSourceConversionOptions;
import de.java2html.options.JavaSourceStyleTable;

/**
 * The main plugin class to be used in the desktop.
 */
public class Java2HtmlPlugin extends AbstractUIPlugin {
  private static Java2HtmlPlugin plugin;
   
  public Java2HtmlPlugin(IPluginDescriptor descriptor) {
    super(descriptor);
    plugin = this;
  }

  public static Java2HtmlPlugin getDefault() {
    return plugin;
  }

  public static IWorkspace getWorkspace() {
    return ResourcesPlugin.getWorkspace();
  }
    
  protected void initializeDefaultPluginPreferences(){
    IPreferenceStore preferenceStore = getPreferenceStore();
    ConversionOptionsPreferencesConverter.initDefaults(preferenceStore);
    preferenceStore.setDefault(IConversionOptionsConstants.DEFAULT_STYLE_NAME, JavaSourceStyleTable.getDefault().getName());
  }
  
  public JavaSourceConversionOptions getConversionOptions() {
    return ConversionOptionsPreferencesConverter.load(getPreferenceStore()); 
  }
  
  public void setConversionOptions(JavaSourceConversionOptions options){
    ConversionOptionsPreferencesConverter.store(options, getPreferenceStore());
  }

  public String getDefaultStyleTableName() {
    return getPreferenceStore().getString(IConversionOptionsConstants.DEFAULT_STYLE_NAME);
  }

  public void setDefaultStyleTableName(String name) {
    getPreferenceStore().setValue(IConversionOptionsConstants.DEFAULT_STYLE_NAME, name);
  }
}