package de.java2html.eclipse.preferences;

import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.PreferenceConverter;
import org.eclipse.swt.graphics.RGB;

import de.java2html.javasource.JavaSourceType;
import de.java2html.options.IConversionOptionsConstants;
import de.java2html.options.JavaSourceConversionOptions;
import de.java2html.options.JavaSourceStyleEntry;
import de.java2html.options.JavaSourceStyleTable;

/**
 * @author Markus Gebhard
 */
public class ConversionOptionsPreferencesConverter {
  public static void initDefaults(IPreferenceStore store) {
    JavaSourceConversionOptions defaultOptions = JavaSourceConversionOptions.getDefault(); 
    
    JavaSourceStyleTable colorTable = defaultOptions.getStyleTable();
    JavaSourceType[] allTypes = JavaSourceType.getAll();
    for (int i=0;i<allTypes.length;++i){
      JavaSourceStyleEntry style = colorTable.get(allTypes[i].getName());
      de.java2html.util.RGB color = style.getColor();
      PreferenceConverter.setDefault(store, allTypes[i].getName(), color2RGB(color));
      store.setDefault(allTypes[i].getName()+IConversionOptionsConstants.POSTFIX_BOLD, style.isBold());
      store.setDefault(allTypes[i].getName()+IConversionOptionsConstants.POSTFIX_ITALIC, style.isItalic());
    }

    store.setDefault(IConversionOptionsConstants.TAB_SIZE, defaultOptions.getTabSize()); 
    store.setDefault(IConversionOptionsConstants.SHOW_LINE_NUMBERS, defaultOptions.isShowLineNumbers());
    store.setDefault(IConversionOptionsConstants.SHOW_FILE_NAME, defaultOptions.isShowFileName()); 
    store.setDefault(IConversionOptionsConstants.SHOW_TABLE_BORDER, defaultOptions.isShowTableBorder()); 
  }

  public static void store(JavaSourceConversionOptions options, IPreferenceStore store){
    JavaSourceStyleTable colorTable = options.getStyleTable();
    JavaSourceType[] allTypes = JavaSourceType.getAll();
    for (int i=0;i<allTypes.length;++i){
      JavaSourceStyleEntry style = colorTable.get(allTypes[i].getName());
      de.java2html.util.RGB color = style.getColor();
      PreferenceConverter.setValue(store, allTypes[i].getName(), color2RGB(color));
      store.setValue(allTypes[i].getName()+IConversionOptionsConstants.POSTFIX_BOLD, style.isBold());
      store.setValue(allTypes[i].getName()+IConversionOptionsConstants.POSTFIX_ITALIC, style.isItalic());
    }

    store.setValue(IConversionOptionsConstants.TAB_SIZE, options.getTabSize()); 
    store.setValue(IConversionOptionsConstants.SHOW_LINE_NUMBERS, options.isShowLineNumbers());
    store.setValue(IConversionOptionsConstants.SHOW_FILE_NAME, options.isShowFileName()); 
    store.setValue(IConversionOptionsConstants.SHOW_TABLE_BORDER, options.isShowTableBorder()); 
  }

  public static JavaSourceConversionOptions load(IPreferenceStore store) {
    JavaSourceStyleTable colorTable = JavaSourceStyleTable.getDefault();
    JavaSourceType[] allTypes = JavaSourceType.getAll();
    for (int i=0;i<allTypes.length;++i){
      de.java2html.util.RGB color = rgb2Color(PreferenceConverter.getColor(store, allTypes[i].getName()));
      boolean bold = store.getBoolean(allTypes[i].getName()+IConversionOptionsConstants.POSTFIX_BOLD);
      boolean italic = store.getBoolean(allTypes[i].getName()+IConversionOptionsConstants.POSTFIX_ITALIC);
      JavaSourceStyleEntry styleEntry = new JavaSourceStyleEntry(color, bold, italic);
      colorTable.put(allTypes[i], styleEntry);
    }

    JavaSourceConversionOptions options = JavaSourceConversionOptions.getDefault();
    options.setStyleTable(colorTable);
    options.setTabSize(store.getInt(IConversionOptionsConstants.TAB_SIZE));
    options.setShowLineNumbers(store.getBoolean(IConversionOptionsConstants.SHOW_LINE_NUMBERS));
    options.setShowFileName(store.getBoolean(IConversionOptionsConstants.SHOW_FILE_NAME));
    options.setShowTableBorder(store.getBoolean(IConversionOptionsConstants.SHOW_TABLE_BORDER));
    return options;
  }

  private static de.java2html.util.RGB rgb2Color(RGB rgb) {
    return new de.java2html.util.RGB(rgb.red, rgb.green, rgb.blue);
  }

  private static RGB color2RGB(de.java2html.util.RGB color) {
    return new RGB(color.getRed(), color.getGreen(), color.getBlue());
  }
}